@@ -20,6 +20,65 @@ library("SimInf")
 ## For debugging
 sessionInfo()
 
+## Check that invalid arguments to mparse raises error
+res <- tools::assertError(
+                  mparse(compartments = c("D","W"),
+                         gdata = c(c1 = 0.5, c2 = 1, c3 = 0.005, c4 = 0.6),
+                         u0 = data.frame(D = 10, W = 10), tspan = 1:5))
+stopifnot(length(grep("'transitions' must be specified.",
+                      res[[1]]$message)) > 0)
+
+res <- tools::assertError(
+                  mparse(transitions = 5,
+                         compartments = c("D","W"),
+                         gdata = c(c1 = 0.5, c2 = 1, c3 = 0.005, c4 = 0.6),
+                         u0 = data.frame(D = 10, W = 10), tspan = 1:5))
+stopifnot(length(grep("'transitions' must be specified in a character vector.",
+                      res[[1]]$message)) > 0)
+
+res <- tools::assertError(
+                  mparse(transitions = c("@->c1->D", "D->c2*D->D+D",
+                                         "D+W->c3*D*W->W+W","W->c4*W->@"),
+                         gdata = c(c1 = 0.5, c2 = 1, c3 = 0.005, c4 = 0.6),
+                         u0 = data.frame(D = 10, W = 10), tspan = 1:5))
+stopifnot(length(grep("'compartments' must be specified.",
+                      res[[1]]$message)) > 0)
+
+res <- tools::assertError(
+                  mparse(transitions = c("@->c1->D", "D->c2*D->D+D",
+                                         "D+W->c3*D*W->W+W","W->c4*W->@"),
+                         compartments = 5,
+                         gdata = c(c1 = 0.5, c2 = 1, c3 = 0.005, c4 = 0.6),
+                         u0 = data.frame(D = 10, W = 10), tspan = 1:5))
+stopifnot(length(grep("'compartments' must be specified in a character vector.",
+                      res[[1]]$message)) > 0)
+
+res <- tools::assertError(
+                  mparse(transitions = c("@->c1->D", "D->c2*D->D+D",
+                                         "D+W->c3*D*W->W+W","W->c4*W->@"),
+                         compartments = c("D","W"),
+                         u0 = data.frame(D = 10, W = 10), tspan = 1:5))
+stopifnot(length(grep("'gdata' must be specified.",
+                      res[[1]]$message)) > 0)
+
+res <- tools::assertError(
+                  mparse(transitions = c("@->c1->D", "D->c2*D->D+D",
+                                         "D+W->c3*D*W->W+W","W->c4*W->@"),
+                         compartments = c("D","W"),
+                         gdata = letters,
+                         u0 = data.frame(D = 10, W = 10), tspan = 1:5))
+stopifnot(length(grep("'gdata' must be a named numeric vector.",
+                      res[[1]]$message)) > 0)
+
+res <- tools::assertError(
+                  mparse(transitions = c("@->c1->D", "D->c2*D->D+D",
+                                         "D+W->c3*D*W->W+W","W->c4*W->@"),
+                         compartments = c("D","W"),
+                         gdata = c(c1 = 0.5, c2 = 1, c3 = 0.005, c4 = 0.6, c1 = 2),
+                         u0 = data.frame(D = 10, W = 10), tspan = 1:5))
+stopifnot(length(grep("'compartments' and 'gdata' must consist of unique names.",
+                      res[[1]]$message)) > 0)
+
 ## Check mparse
 m <- mparse(transitions = c("@->c1->D", "D->c2*D->D+D",
                             "D+W->c3*D*W->W+W","W->c4*W->@"),
